# Generated by Django 3.1.5 on 2021-02-19 18:37

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import rest_avatar.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Avatar',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_primary', models.BooleanField(default=False)),
                ('avatar', models.ImageField(upload_to=rest_avatar.models.avatar_file_path)),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='avatars', to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
